ocpa.algo.enhancement.event\_graph\_based\_performance package
==============================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ocpa.algo.enhancement.event_graph_based_performance.versions

Submodules
----------

ocpa.algo.enhancement.event\_graph\_based\_performance.algorithm module
-----------------------------------------------------------------------

.. automodule:: ocpa.algo.enhancement.event_graph_based_performance.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: ocpa.algo.enhancement.event_graph_based_performance
   :members:
   :undoc-members:
   :show-inheritance:
